function [idx,Ethreshold,specdat_out] = OptimNbinsThresholds(specdat,nbins,varargin)
%  function [idx,Ethreshold,specnum] = OptimNbinsThresholds(specdat,nbins,varargin)
%  Determine optimal thresholds for given spectrum
%  Adjusts thresholds so each bin has equal number of counts
%  inputs:
%     specdat: an array giving specnum or a spectrum structure with fields: specnum and egys
%     nbins: the number of bins
%     zA: (optional = 0) additional attenuator
%  outputs:
%     idx: an (nbins-1) integer array of the indexes into the egys array for the optimal thresholds
%     Ethreshold: the corresponding energies
%     specnum: the output spectrum struct after attenuating(note that
%          number of photons may have been adjusted)
%  REA 2/13-8/23/10

  % process the optional arguments
nreqargs = 2;
assert(nargin>=nreqargs);
zA = 0;
if(nargin>nreqargs)
  i=1;
  while(i<=size(varargin,2))
     switch lower(varargin{i})
     case 'max';          minmax=1;
     case 'za';         zA=varargin{i+1};    i=i+1;
    otherwise
      error('Unknown argument %s given',varargin{i});
     end
     i=i+1;
  end
end

assert( isstruct(specdat) );
    % attenuate the spectrum if zmus present
if abs(zA) ~= 0    
    zmus = zcomp(specdat.mus);
    Transmission_E = exp(-[real(zmus(:)) imag(zmus(:))]*[real(zA); imag(zA)])';
    specdat.specnum = specdat.specnum(:).*Transmission_E(:);
end
specnum = specdat.specnum;
if sum(specnum) < 1000 % make sure sum(specnum) big enough so can do integer calcs below
    specnum = 1000*specnum/sum(specnum);
end
specdat_out = specdat;
specdat_out.specnum = specnum;
integral = cumsum(specnum);
idx = zeros(nbins-1,1);
for k = 1:(nbins-1)
   idx(k) = find(integral< floor(k*integral(end)/nbins),1,'last');
end
Ethreshold = specdat.egys(idx);