% P29D2kbin.m KbinPHA_SNR
% COPYRIGHT:  Aprend Technology, 2011. All rights reserved.
 
%% init vars
post_title = 'P29D2kbin';
dirname = ['E:\Projects\Blog\Posts\' post_title '\'];
addpath('E:\Projects\DEsolvePaper\Code');

%% generate specdatrum, mu data, and ideal SNR^2
      % specdatrum
tube_voltage = 120; % keV  
[specnum,xray_energies] = XrayTubeSpectrumTasmip(tube_voltage,'number_spectrum');
   % create the spectrum data (specdat) struct--interpolate to higher resolution
specdat.egys = linspace(min(xray_energies),max(xray_energies),10000);
specdat.specnum = interp1(xray_energies,specnum,specdat.egys);
nphotons = 10^5; % number of photons in incident beam  
specdat.specnum = nphotons*specdat.specnum(:)/sum(specnum(:)); % normalize so can adjust Ninit easily later
   % mu data
materials = {'Al','C5O2H8'};
rhos = [2.699 1.19];
mus =  [rhos(1)*xraymu(materials{1},specdat.egys) rhos(2)*xraymu(materials{2},specdat.egys)];
specdat.mus = mus;
specdat.dmus = diff(mus,1,2); % difference along rows


%% compute SNR^2 vs nbins and object thickness
nbins_all = 2:4:100;
snr_nbins = zeros(numel(nbins_all),1);
lambdas = zeros(numel(nbins_all),1);
zAs = geospace(0,2.5,4)' + 1i*geospace(0,15,4)'; % different thicknesses along a diagonal line
zAs = flipud(zAs); % puts legend in order or lines
fh = figure;
colors = 'krbg';
styles = {'-','-*','-.','--'};
linewid = 1.5;
hold on
for kthick = 1:numel(zAs)
          % attenuate spectrum
    zA = zAs(kthick);
    A = zcomp(zA)'; % cm of Al and plastic
    specout = specdat;
    specout.specnum = specdat.specnum.*exp(-specdat.mus*A);
    snr2_ideal = sum(specout.specnum.*((specout.dmus).^2));
    k = 1;
    for nbins = nbins_all
        [idxs_threshold, Ethreshold] = OptimNbinsThresholds(specout,nbins); % threshold indexes
        bin_edges = [0; idxs_threshold(:);numel(specout.egys)];
        snr2 = 0;
        lambdas(k) = 0;
        for kbin = 1:nbins
           idxs =  (bin_edges(kbin)+1):bin_edges(kbin+1); 
           lambda_k = sum(specout.specnum(idxs));
           spec_norm = specout.specnum(idxs)/lambda_k;
           snr2 = snr2 + lambda_k*(sum(spec_norm.*specout.dmus(idxs)))^2;
           lambdas(k) = lambdas(k) + lambda_k;
        end
        snr_nbins(k) = snr2;
        
        k = k + 1;
    end
    plot(nbins_all,snr_nbins/snr2_ideal,[styles{kthick} colors(kthick)],'linewidth',linewid)
end
hold off
xlabel('number of bins','fontsize',13);
ylabel('SNR^2/SNR^2_{ideal}','fontsize',13);
set(gca,'fontsize',13,'linewidth',1.5);
axis([0 max(nbins_all) 0.5 1])
hl = legend(num2str(abs(zAs),'%5.1f'),'location','southeast');
ht = text(55,0.75,'object thickness (cm)','fontsize',13);
set(fh,'color','w','position',[250 250 550 350])

%% export the figure as png and eps
figno = sprintf('-f%d',fh);
fname = 'SNRvsNbins';
   % export as eps
exportfig(fh,[dirname fname '.eps'],'width',5,'LockAxes',0,'color','cmyk');
set(fh,'papertype','usletter')
print(figno,'-dpng','-cmyk','-r100',[dirname fname '.png']) % resolution 100 dpi